package PlayBot::utils::print;

use strict;
use warnings;

use IRC::Utils qw(YELLOW ORANGE GREEN NORMAL LIGHT_BLUE GREY);

# Used to print a content.
# The public subroutine is print($content).
# arg :
#   - $content : a ref to a hash with the following keys :
#       - author
#       - duration (in seconds)
#       - external_id (optional)
#       - id
#       - site (if external_id)
#       - tags : a ref to a list of tags
#       - title
#       - url
# returns :
#   - a string well formated

sub print
{
    my ($content) = @_;

    if (defined($content->{external_id}) and defined($content->{site}))
    {
        my $site = 'PlayBot::sites::'.$content->{site};
        eval "require $site";
        eval { $content->{url} = $site->get_url($content->{external_id}) };
        # TOOD: log if $@
    }

    my $msg = YELLOW.'['.$content->{'id'}.'] '.GREEN.$content->{'title'};

	if (defined $content->{'author'})
    {
		$msg .= ' | '.$content->{'author'};
	}

    if (defined $content->{'duration'})
    {
        my $h = int($content->{'duration'} / 3600);
        my $m = int(($content->{'duration'} % 3600) / 60);
        my $s = int(($content->{'duration'} % 3600) % 60);

        $msg .= LIGHT_BLUE.' (';
        $msg .= sprintf("%02d:", $h) if ($h > 0);
        $msg .= sprintf("%02d:", $m);
        $msg .= sprintf("%02d", $s);
        $msg .= ')'.NORMAL;
    }

    $msg .= ' => '.$content->{'url'}.ORANGE if (defined $content->{'url'});

    if (defined $content->{'tags'})
    {
        $msg .= ' '.$_ foreach (@{$content->{'tags'}});
    }

    $msg .= GREY;

    return $msg;
}

sub stats
{
    # a utils::db::stats object;
    my $stats = shift;
    my $line1; 
    my $line2;
    my $line3;
    my $line4;

    $line1 .= 'Posté la 1re fois par '.$stats->sender;
    $line1 .= ' le '.$stats->date;
    $line1 .= ' sur '.$stats->chan;

    if ($stats->count > 1)
    {
        my $senders_count = keys %{$stats->senders};
        my $channels_count = keys %{$stats->channels};

        $line2 .= 'Posté '.$stats->count.' fois';
        $line2 .= ' par '.$senders_count.' personne';
        $line2 .= 's' if ($senders_count > 1);
        $line2 .= ' sur '.$channels_count.' channel';
        $line2 .= 's' if ($channels_count > 1);

        my $max_sender_count = $stats->senders->{$stats->max_sender};
        if ($max_sender_count > 1)
        {
            $line3 .= $stats->max_sender. " l'a posté ";
            $line3 .= $max_sender_count. ' fois';
        }

        my $max_channel_count = $stats->channels->{$stats->max_channel};
        if ($max_channel_count != $stats->count and $max_channel_count > 1)
        {
            $line3 .= ' et ' if ($max_sender_count > 1);
            $line3 .= 'il a été posté '.$max_channel_count;
            $line3 .= ' fois sur '.$stats->max_channel;
        }
    }

    if ($stats->fav)
    {
        $line4 = "Sauvegardé dans ses favoris par ";
        $line4 .= $stats->fav.' personne';
        $line4 .= 's' if ($stats->fav > 1);
    }

    return ($line1, $line2, $line3, $line4);
}

1;
